import { BizError } from "../../util/bizError";
import { getInterfaceByInterfaceName } from "./cronJob";

export async function getQjnygfjr() {
    let interfaceName = "绿色电力清洁能源光伏接入";
    let {totalCustomer, realTimeMonitoring, distributedPvCustomerTrends, distributedPhotovoltaicCustomer, powerAnalysis} = await getInterfaceByInterfaceName(interfaceName);
    
    if (JSON.stringify(totalCustomer) === '{}') totalCustomer = {residentCustomer:0, nonResidentCustomer:0};
    if (JSON.stringify(realTimeMonitoring) === '{}') realTimeMonitoring = {NO2:0, SO2:0, CO2:0};
    if (JSON.stringify(distributedPhotovoltaicCustomer) === '{}') distributedPhotovoltaicCustomer = {distributedPvCustomer:0, proportionOfNonResidents:0};

    if (!totalCustomer) throw new BizError(`${interfaceName} 缺少参数 totalCustomer` );
    if (!realTimeMonitoring) throw new BizError(`${interfaceName} 缺少参数 realTimeMonitoring` );
    if (!distributedPvCustomerTrends) throw new BizError(`${interfaceName} 缺少参数 distributedPvCustomerTrends` );
    if (!distributedPhotovoltaicCustomer) throw new BizError(`${interfaceName} 缺少参数 distributedPhotovoltaicCustomer` );
    if (!powerAnalysis) throw new BizError(`${interfaceName} 缺少参数 powerAnalysis` );

    let {residentCustomer, nonResidentCustomer} = totalCustomer;
    //客户总量
    let customerInfo = {
        居民客户: residentCustomer,
        非居民客户: nonResidentCustomer
    };

    //各类污染物减排占比
    let {NO2, CO2, SO2} = realTimeMonitoring;
    let realTimeInfo = {
        NO2: NO2 + "吨",
        CO2: CO2 + "吨",
        SO2: SO2 + "吨"
    };

    //分布式光伏客户接入变化趋势
    let distributed = {};
    distributedPvCustomerTrends.forEach( info => {
        let {year, value} = info;
        distributed[year] = value + "户";
    })

    let {distributedPvCustomer, proportionOfNonResidents} = distributedPhotovoltaicCustomer;
    //分布式光伏客户
    let distributedInfo = {
        分布式光伏客户:distributedPvCustomer + "户",
        非居民占比:proportionOfNonResidents + "%"
    };

    //近12个月电量分析
    let powerAnalysisInfo;
    let powerGenerationData = {};
    let theInternetChargeData = {};
    powerAnalysis.forEach( info => {
        let {month, powerGeneration, theInternetCharge} = info;
        powerGenerationData[month] = powerGeneration + "万kwh";
        theInternetChargeData[month] = theInternetCharge + "万kwh";
    })
    powerAnalysisInfo = {发电量: powerGenerationData, 上网电量: theInternetChargeData};

    return {customerInfo, realTimeInfo, distributed, distributedInfo, powerAnalysisInfo};
}

export async function getPowerGeneration() {
    let interfaceName = "绿色电力清洁能源光伏接入";
    let {totalGeneratingCapacity} = await getInterfaceByInterfaceName(interfaceName);
    
    if (JSON.stringify(totalGeneratingCapacity) === '{}') totalGeneratingCapacity = {grossGeneration:0, proportionOfNonResidents:0};

    if (!totalGeneratingCapacity) throw new BizError(`${interfaceName} 缺少参数 totalGeneratingCapacity` );

    //总发点量
    let {grossGeneration, proportionOfNonResidents} = totalGeneratingCapacity;
    let powerGenerationInfo = {
        总发电量:grossGeneration + "亿千瓦时",
        非居民占比:proportionOfNonResidents + "%"
    };

    return {powerGenerationInfo};
}

export async function getInstalledCapacity() {
    let interfaceName = "绿色电力清洁能源光伏接入";
    let {theInstalledCapacity} = await getInterfaceByInterfaceName(interfaceName);
    
    if (JSON.stringify(theInstalledCapacity) === '{}') theInstalledCapacity = {installedCapacity:0, proportionOfNonResidents:0};

    if (!theInstalledCapacity) throw new BizError(`${interfaceName} 缺少参数 theInstalledCapacity` );

    //装机容量
    let {installedCapacity, proportionOfNonResidents} = theInstalledCapacity;
    let installedCapacityInfo = {
        装机容量:installedCapacity + "万千伏安",
        非居民占比:proportionOfNonResidents + "%"
    };

    return {installedCapacityInfo};
}