import { BizError } from "../../util/bizError";
import { getInterfaceByInterfaceName } from "./cronJob";

export async function getQydzxypg() {
    let interfaceName = "企业贷中信用评估";
    let {distributionOfEachCreditRating, highQualityCreditEnterprise, ventureEnterprise, monthlyBusinessCreditChanges, industryCreditDistribution, rangeData} = await getInterfaceByInterfaceName(interfaceName);

    if (JSON.stringify(distributionOfEachCreditRating) === '{}') distributionOfEachCreditRating = {excellentCredit:0, goodCredit:0, generalCredit:0, poorCredit:0};
    if (JSON.stringify(rangeData) === '{}') rangeData = {regionalScope:"", timeRange:""};

    if (!distributionOfEachCreditRating) throw new BizError(`${interfaceName} 缺少参数 distributionOfEachCreditRating` );
    if (!highQualityCreditEnterprise) throw new BizError(`${interfaceName} 缺少参数 highQualityCreditEnterprise` );
    if (!ventureEnterprise) throw new BizError(`${interfaceName} 缺少参数 ventureEnterprise` );
    if (!monthlyBusinessCreditChanges) throw new BizError(`${interfaceName} 缺少参数 monthlyBusinessCreditChanges` );
    if (!rangeData) throw new BizError(`${interfaceName} 缺少参数 rangeData` );

    //各信用等级企业分布情况
    let {excellentCredit, goodCredit, generalCredit, poorCredit} = distributionOfEachCreditRating;
    let distributionInfo = {
        信用极好: excellentCredit + "户",
        信用良好: goodCredit + "户",
        信用一般: generalCredit + "户",
        信用差: poorCredit + "户"
    };

    //优质信用企业
    let highQuality = {};
    highQualityCreditEnterprise.sort(function(a, b) {
        return a.value - b.value;
    });
    highQualityCreditEnterprise.forEach( info => {
        let {companyName, value} = info;
        highQuality[companyName] = value;
    })

    //风险企业
    let venture = {};
    ventureEnterprise.sort(function(a, b) {
        return a.value - b.value;
    });
    ventureEnterprise.forEach( info => {
        let {companyName, value} = info;
        venture[companyName] = value;
    })

    //每月企业信用变化趋势
    let monthlyBusinessInfo;
    let excellentCreditData = {};
    let goodCreditData = {};
    let generalCreditData = {};
    let poorCreditData = {};
    monthlyBusinessCreditChanges.forEach( info => {
        let {month, excellentCredit, goodCredit, generalCredit, poorCredit} = info;
        let monthly = month;
        excellentCreditData[monthly] = excellentCredit;
        goodCreditData[monthly] = goodCredit;
        generalCreditData[monthly] = generalCredit;
        poorCreditData[monthly] = poorCredit;
    })
    monthlyBusinessInfo = {信用极好: excellentCreditData, 信用良好: goodCreditData, 信用一般: generalCreditData, 信用差: poorCreditData}

    //范围数据
    let {regionalScope, timeRange} = rangeData;
    let rangeInfo = {
        "区域范围": regionalScope,
        "时间范围": timeRange
    };

    return {distributionInfo, highQuality, venture, monthlyBusinessInfo, rangeInfo};
}

export async function getindustryCredit() {
    let interfaceName = "企业贷中信用评估";
    let {industryCreditDistribution} = await getInterfaceByInterfaceName(interfaceName);

    if (!industryCreditDistribution) throw new BizError(`${interfaceName} 缺少参数 industryCreditDistribution` );

    //行业信用分布对比
    let industryCreditInfo;
    let excellentCreditData = {};
    let goodCreditData = {};
    let generalCreditData = {};
    let poorCreditData = {};
    industryCreditDistribution.forEach( info => {
        let {industryName, excellentCredit, goodCredit, generalCredit, poorCredit} = info;
        excellentCreditData[industryName] = excellentCredit;
        goodCreditData[industryName] = goodCredit;
        generalCreditData[industryName] = generalCredit;
        poorCreditData[industryName] = poorCredit;
    })
    industryCreditInfo = {信用极好: excellentCreditData, 信用良好: goodCreditData, 信用一般: generalCreditData, 信用差: poorCreditData}

    return {industryCreditInfo};
}
