import { BizError } from "../../util/bizError";
import { getInterfaceByInterfaceName } from "./cronJob";

export async function getSqjjhl() {
    let interfaceName = "商圈经济活力";
    let {basicData, CIIEHolidayVitalityIndex, zhaoXiangDistrictHolidayVitalityIndex, qingPuNewTownHolidayVitalityIndex, zhuJiaJiaoHolidayVitalityIndex,
        qingPuKeyBusinessDistrictIndex, CIIEConsumptionTypeAnalysis, zhaoXiangConsumptionTypeAnalysis, zhuJiaJiaoConsumptionTypeAnalysis, 
        qingPuNewTownConsumptionTypeAnalysis, qingPuEconomicVitalityTrend, rangeData} = await getInterfaceByInterfaceName(interfaceName);
        
    if (JSON.stringify(basicData) === '{}') basicData = {overallEconomicVitalityIndex:"0"};
    if (JSON.stringify(rangeData) === '{}') rangeData = {regionalScope:"", timeRange:""};

    if (!basicData) throw new BizError(`${interfaceName} 缺少参数 basicData` );
    if (!CIIEHolidayVitalityIndex) throw new BizError(`${interfaceName} 缺少参数 CIIEHolidayVitalityIndex` );
    if (!zhaoXiangDistrictHolidayVitalityIndex) throw new BizError(`${interfaceName} 缺少参数 zhaoXiangDistrictHolidayVitalityIndex` );
    if (!qingPuNewTownHolidayVitalityIndex) throw new BizError(`${interfaceName} 缺少参数 qingPuNewTownHolidayVitalityIndex` );
    if (!zhuJiaJiaoHolidayVitalityIndex) throw new BizError(`${interfaceName} 缺少参数 zhuJiaJiaoHolidayVitalityIndex` );
    if (!qingPuKeyBusinessDistrictIndex) throw new BizError(`${interfaceName} 缺少参数 qingPuKeyBusinessDistrictIndex` );
    if (!CIIEConsumptionTypeAnalysis) throw new BizError(`${interfaceName} 缺少参数 CIIEConsumptionTypeAnalysis` );
    if (!zhaoXiangConsumptionTypeAnalysis) throw new BizError(`${interfaceName} 缺少参数 zhaoXiangConsumptionTypeAnalysis` );
    if (!zhuJiaJiaoConsumptionTypeAnalysis) throw new BizError(`${interfaceName} 缺少参数 zhuJiaJiaoConsumptionTypeAnalysis` );
    if (!qingPuNewTownConsumptionTypeAnalysis) throw new BizError(`${interfaceName} 缺少参数 qingPuNewTownConsumptionTypeAnalysis` );
    if (!qingPuEconomicVitalityTrend) throw new BizError(`${interfaceName} 缺少参数 qingPuEconomicVitalityTrend` );
    if (!rangeData) throw new BizError(`${interfaceName} 缺少参数 rangeData` );

    let {overallEconomicVitalityIndex} = basicData;
    let basicInfo = {总体经济活力指数: overallEconomicVitalityIndex};

    //进博会核心区节假日活力指数分析
    let CIIEHoliday = getHolidayVitalityIndex(CIIEHolidayVitalityIndex);

    //赵巷区节假日活力指数分析
    let zhaoXiangDistrictHoliday= getHolidayVitalityIndex(zhaoXiangDistrictHolidayVitalityIndex);

    //青浦新城节假日活力指数分析
    let qingPuNewTownHoliday = getHolidayVitalityIndex(qingPuNewTownHolidayVitalityIndex);

    //朱家角古镇节假日活力指数分析
    let zhuJiaJiaoHoliday = getHolidayVitalityIndex(zhuJiaJiaoHolidayVitalityIndex);

    //青浦重点商圈经济活力指数
    let qingPuKeyBusiness= getKeyBusinessDistrictIndex(qingPuKeyBusinessDistrictIndex);

    //进博会核心区消费类型分析
    let CIIEConsumption = getMonthData(CIIEConsumptionTypeAnalysis);

    //赵巷区消费类型分析
    let zhaoXiangConsumption = getMonthData(zhaoXiangConsumptionTypeAnalysis);

    //朱家角古镇区消费类型分析
    let zhuJiaJiaoConsumption = getMonthData(zhuJiaJiaoConsumptionTypeAnalysis);

    //青浦新城消费类型分析
    let qingPuNewTownConsumption = getMonthData(qingPuNewTownConsumptionTypeAnalysis);

    //青浦重点商圈经济活力变化趋势
    let qingPuEconomicVitalityTrendData;
    let qingPuNewTownData = {};
    let CIIECoreAreaData = {};
    let zhaoXiangCommercialBusinessData = {};
    let zhuJiaJiaoAncientTownData = {};
    qingPuEconomicVitalityTrend.forEach( info => {
        let {month, qingPuNewTown, CIIECoreArea, zhaoXiangCommercialBusiness, zhuJiaJiaoAncientTown} = info;
        qingPuNewTownData[month] = qingPuNewTown;
        CIIECoreAreaData[month] = CIIECoreArea;
        zhuJiaJiaoAncientTownData[month] = zhuJiaJiaoAncientTown;
        zhaoXiangCommercialBusinessData[month] = zhaoXiangCommercialBusiness;
    })
    qingPuEconomicVitalityTrendData = {青浦新城: qingPuNewTownData, 赵巷商业商务: CIIECoreAreaData, 朱家角古镇: zhaoXiangCommercialBusinessData, 进博会核心区: zhuJiaJiaoAncientTownData};

    //范围数据
    let {regionalScope, timeRange} = rangeData;
    let rangeInfo = {
        "区域范围": regionalScope,
        "时间范围": timeRange
    };

    return {basicInfo, CIIEHoliday, zhaoXiangDistrictHoliday, qingPuNewTownHoliday, zhuJiaJiaoHoliday, 
        qingPuKeyBusiness, CIIEConsumption, zhaoXiangConsumption, zhuJiaJiaoConsumption, qingPuNewTownConsumption, qingPuEconomicVitalityTrendData, rangeInfo};
}

//获取节假日活力指数分析
function getHolidayVitalityIndex(dataList) {
    let dataInfo;
    let eatData = {};
    let liveData = {};
    let gameData = {};
    let entertainmentData = {};
    let shoppingData = {};
    dataList.forEach( info => {
        let {holidayName, eat, live, game, entertainment, shopping} = info;
        eatData[holidayName] = eat;
        liveData[holidayName] = live;
        gameData[holidayName] = game;
        entertainmentData[holidayName] = entertainment;
        shoppingData[holidayName] = shopping;
    })
    dataInfo = {吃: eatData, 住: liveData, 游: gameData, 娱: entertainmentData, 购: shoppingData};

    return dataInfo;
}

//获取商圈经济活力指数
function getKeyBusinessDistrictIndex(dataList) {
    let dataInfo;
    let currYearData = {}; //当年
    let lastYearData = {}; //去年
    let yoyGrowthData = {}; //同比
    dataList.forEach( info => {
        let {businessName, currYear, lastYear, yoyGrowth} = info;
        currYearData[info.businessName] = currYear;
        lastYearData[businessName] = lastYear;
        yoyGrowthData[businessName] = yoyGrowth;
    })
    dataInfo = {'2022年': lastYearData, '2023年': currYearData, '2023年同比增长': yoyGrowthData};

    return dataInfo;
}

function getMonthData(dataList) {
    let dataInfo;
    let eatData = {};
    let liveData = {};
    let gameData = {};
    let entertainmentData = {};
    let shoppingData = {};
    dataList.forEach( info => {
        let {month, eat, live, game, entertainment, shopping} = info;
        eatData[month] = eat;
        liveData[month] = live;
        gameData[month] = game;
        entertainmentData[month] = entertainment;
        shoppingData[month] = shopping;
    })
    dataInfo = {吃: eatData, 住: liveData, 游: gameData, 娱: entertainmentData, 购: shoppingData};

    return dataInfo;
}